import './libs/webaudio-controls.js';

const getBaseURL = () => {
	return new URL('.', import.meta.url);
};

const template = document.createElement("template");
template.innerHTML = /*html*/`
  <style>
  </style>
  <audio id="myPlayer"></audio>
    <br>
    <webaudio-knob id="volumeKnob" 
      src="./assets/imgs/LittlePhatty.png" 
      value=5 min=0 max=20 step=0.01 
      diameter="32" 
      tooltip="Volume: %d">
    </webaudio-knob>
  <button id="play">Play</button> 
  <button id="pause">Pause</button>
  <button id="avance10">+10s</button>
  <br>
  <label>Vitesse de lecture
     0 <input id="vitesseLecture" type="range" min=0.2 max=4 step=0.1 value=1> 4
  </label>
  `;

class MyAudioPlayer extends HTMLElement {
    constructor() {
        super();
        // Récupération des attributs HTML
        //this.value = this.getAttribute("value");

        // On crée un shadow DOM
        this.attachShadow({ mode: "open" });

        console.log("URL de base du composant : " + getBaseURL())
    }

    connectedCallback() {
        // Appelée automatiquement par le browser
        // quand il insère le web component dans le DOM
        // de la page du parent..

        // On clone le template HTML/CSS (la gui du wc)
        // et on l'ajoute dans le shadow DOM
        this.shadowRoot.appendChild(template.content.cloneNode(true));
 
        // fix relative URLs
        this.fixRelativeURLs();

        this.player = this.shadowRoot.querySelector("#myPlayer");
        this.player.src = this.getAttribute("src");

        // on définit les écouteurs etc.
        this.defineListeners();
    }

    fixRelativeURLs() {
        const elems = this.shadowRoot.querySelectorAll("webaudio-knob, webaudio-slider, webaudio-switch, img");
        elems.forEach(e => {
            const path = e.src;
            if(path.startsWith(".")) {
                e.src = getBaseURL() + path;
            }
        });
  }
    defineListeners() {
        this.shadowRoot.querySelector("#play").onclick = () => {
            this.player.play();
        }

        this.shadowRoot.querySelector("#pause").onclick = () => {
            this.player.pause();
        }

        this.shadowRoot.querySelector("#avance10").onclick = () => {
            this.player.currentTime += 10;
        }

        this.shadowRoot.querySelector("#vitesseLecture").oninput = (event) => {
            this.player.playbackRate = parseFloat(event.target.value);
            console.log("vitesse =  " + this.player.playbackRate);
        }
    }

    // L'API du Web Component

}

customElements.define("my-player", MyAudioPlayer);
